# Architecture Decision Records (ADR)

This is a location to record all high-level architecture decisions in the Umee
project.

You can read more about the ADR concept in this [blog post](https://product.reverb.com/documenting-architecture-decisions-the-reverb-way-a3563bb24bd0#.78xhdix6t).

An ADR should provide:

- Changelog
- Status
- Context on the relevant goals and the current state
- Proposed changes to achieve the goals
- Summary of pros and cons
- References

Note the distinction between an ADR and a spec. The ADR provides the context,
intuition, reasoning, and justification for a change in architecture, or for the
architecture of something new. The spec is much more compressed and streamlined
summary of everything as it stands today.

If recorded decisions turned out to be lacking, convene a discussion, record the
new decisions here, and then modify the code to match.

Note the context/background should be written in the present tense.

## Table of Contents

### Accepted

### Rejected

### Proposed

- [ADR-001: Interest Stream](./ADR-001-interest-stream.md)
- [ADR-002: Deposit Assets](./ADR-002-deposit-assets.md)
- [ADR-003: Borrow Assets](./ADR-003-borrow-assets.md)
- [ADR-004: Borrow interest implementation and reserves](./ADR-004-interest-and-reserves.md)
- [ADR-005: Liquidation](./ADR-005-liquidation.md)
- [ADR-006: Oracle](./ADR-006-oracle.md)
- [ADR-007: Bad debt](./ADR-007-bad-debt.md)
